
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

#pragma once

            #include <glib-object.h>


            G_BEGIN_DECLS

/* enumerations from "dh-link.h" */


GType dh_link_type_get_type (void);
#define DH_TYPE_LINK_TYPE (dh_link_type_get_type())


GType dh_link_flags_get_type (void);
#define DH_TYPE_LINK_FLAGS (dh_link_flags_get_type())

G_END_DECLS

/* Generated data ends here */

